@@ -490,11 +490,7 @@ public:
         connect(combo, &KeySelectionCombo::currentKeyChanged, q, [this] () {
             updateOkButton();
         });
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
         connect(combo, QOverload<int>::of(&QComboBox::currentIndexChanged), q, [this] () {
-#else
-        connect(combo, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), q, [this] () {
-#endif
             updateOkButton();
         });
 
@@ -575,11 +571,7 @@ public:
             connect(combo, &KeySelectionCombo::currentKeyChanged, q, [this] () {
                 updateOkButton();
             });
-#if QT_VERSION < QT_VERSION_CHECK(5, 15, 0)
             connect(combo, QOverload<int>::of(&QComboBox::currentIndexChanged), q, [this] () {
-#else
-            connect(combo, QOverload<int, const QString &>::of(&QComboBox::currentIndexChanged), q, [this] () {
-#endif
                 updateOkButton();
             });
 
